@@ -75,7 +75,8 @@ void alphamunge_core(PyObject *pysrc,
 void scale32_core(PyObject *pysrc,
                   PyObject *pydst,
                   float, float, float, float,
-                  float, float, float, float);
+                  float, float, float, float,
+                  int);
 
 void scale24_core(PyObject *pysrc,
                   PyObject *pydst,
@@ -87,7 +88,7 @@ void transform32_core(PyObject *pysrc,
                       float, float,
                       float, float,
                       float, float,
-                      int, float);
+                      int, float, int);
 
 void blend32_core(PyObject *pysrca,
                   PyObject *pysrcb,
