@@ -16,7 +16,6 @@ extra_compile_args = [ "-O3", "-funroll-loops" ]
 # extra_compile_args = [ "-O0", "-ggdb" ]
 # extra_compile_args = [ "-O0", "-gstabs" ]
 
-
 # This environment variable should have the full path to the installed
 # Ren'Py dependencies.
 install = os.environ.get("RENPY_DEPS_INSTALL", None)
@@ -75,7 +74,7 @@ def add_include(prefix, file):
     if dir not in include_dirs:
         include_dirs.append(dir)
 
-def add_library(name):
+def add_library(name, optional=False):
     """
     This looks for a library named name in the <i> and <i>/lib, for all
     <i> in install. When found, it adds it to library_dirs.
@@ -96,8 +95,11 @@ def add_library(name):
 
                     if dir not in library_dirs:
                         library_dirs.append(dir)
-                    return
+                    return True
 
+    if optional:
+        return False
+                
     print "Couldn't find library %s." % name
     print "The paths searched were:"
     for i in checked:
@@ -115,21 +117,24 @@ add_include("", "libavcodec/avcodec.h")
 add_include("", "libswscale/swscale.h")
 
 add_library("libSDL")
-add_library("libz")
 add_library("libpng")
 add_library("libavformat")
 add_library("libavcodec")
 add_library("libavutil")
+has_swscale = add_library("libswscale", True)
 add_library("libfreetype")
-            
-
+add_library("libfribidi")            
+add_library("libz")
 
 extra_link_args = [ ]
 
 sdl_libraries = [ 'SDL' ]
-sound_libraries = [ "avformat", "avcodec", "avutil", "z" ]
 png_libraries = [ 'png', "z" ]
 
+sound_libraries = [ "avformat", "avcodec", "avutil", "z" ]
+if has_swscale:
+    sound_libraries.insert(0, "swscale")
+
 # The following turn on optional modules.
 winmixer = None
 linmixer = None
@@ -168,7 +173,7 @@ renpy_font = distutils.core.Extension(
     library_dirs=library_dirs,
     extra_compile_args=extra_compile_args,
     extra_link_args=extra_link_args,
-    libraries=sdl_libraries + [ 'freetype' ],
+    libraries=sdl_libraries + [ 'freetype', 'z' ],
     )
 
 extensions.append(renpy_font)
@@ -197,9 +202,21 @@ if winmixer:
 if linmixer:
     py_modules.append('pysdlsound.linmixer')
 
+
+renpybidi = distutils.core.Extension(
+    "_renpybidi",
+    ["_renpybidi.c", "renpybidicore.c"],
+    include_dirs=include_dirs,
+    library_dirs=library_dirs,
+    libraries=['fribidi'],
+    )
+
+extensions.append(renpybidi)
+
+    
 distutils.core.setup(
     name = "renpy_module",
-    version = "6.9.1",
+    version = "6.10.1",
     ext_modules = extensions,
     py_modules = py_modules,
     package_dir = { '' : 'lib' },
