@@ -142,8 +142,8 @@ def init():
         info = pygame.display.Info()
 
         factor = min(1.0,
-                     1.0 * info.current_w / renpy.config.screen_width,
-                     1.0 * info.current_h / renpy.config.screen_height)
+                     1.0 * 800 / renpy.config.screen_width,
+                     1.0 * 480 / renpy.config.screen_height)
 
         if factor <= 0:
             factor = 1.0
